"use client"

import { useState, useEffect } from "react";
import Link from 'next/link';


import metadata from '@metadata.json'
import servicesData from '@helpers/services.json';
import Share from './Share';

function Nav(props) {
	
		useEffect(() => {
			theme(localStorage.theme ?? "retro");
		}, []);

		const theme = (item) => {
				console.log(item);
				localStorage.theme = item;
				document.querySelector('html').setAttribute('data-theme', item);
		}

		const [services, setServices] = useState(servicesData);

		return (
					<>

						<div className={`navbar bg-[${props.bg}]`} >
							<div className="navbar-start">
								<div className="flex-none">
									<label htmlFor="my-drawer-3" className="btn btn-primary btn-square btn-ghost">
										<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" className="inline-block w-6 h-6 stroke-current"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M4 6h16M4 12h16M4 18h16"></path></svg>
									</label>
								</div>
							</div>
							<div className="navbar-center">
								<Link href="/" className="btn btn-accent btn-ghost normal-case text-xl" style={{color: props.text ?? 'black'}}>{metadata.name}</Link>
							</div>

							<div className="navbar-end">

							<div className="dropdown">
							<label tabIndex={0} className="btn sm:btn-md btn-sm btn-primary m-1">Themes</label>
							<ul tabIndex={0} style={{right:'-50%'}} className="dropdown-content z-[1] menu p-2 shadow-md bg-base-100 space-y-2 max-h-[340px] block overflow-y-scroll rounded-box w-52">


								<button onClick={()=>{theme('light')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="light" data-act-className="[&amp;_svg]:visible">
									<div data-theme="light" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">light</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('dark')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="dark" data-act-className="[&amp;_svg]:visible">
									<div data-theme="dark" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">dark</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('cupcake')}} className="outline-base-content overflow-hidden rounded-lg text-left [&amp;_svg]:visible" data-set-theme="cupcake" data-act-className="[&amp;_svg]:visible">
									<div data-theme="cupcake" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">cupcake</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('bumblebee')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="bumblebee" data-act-className="[&amp;_svg]:visible">
									<div data-theme="bumblebee" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">bumblebee</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('corporate')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="corporate" data-act-className="[&amp;_svg]:visible">
									<div data-theme="corporate" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">corporate</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('retro')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="retro" data-act-className="[&amp;_svg]:visible">
									<div data-theme="retro" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">retro</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('cyberpunk')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="cyberpunk" data-act-className="[&amp;_svg]:visible">
									<div data-theme="cyberpunk" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">cyberpunk</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('valentine')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="valentine" data-act-className="[&amp;_svg]:visible">
									<div data-theme="valentine" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">valentine</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('halloween')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="halloween" data-act-className="[&amp;_svg]:visible">
									<div data-theme="halloween" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">halloween</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('garden')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="garden" data-act-className="[&amp;_svg]:visible">
									<div data-theme="garden" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">garden</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('forest')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="forest" data-act-className="[&amp;_svg]:visible">
									<div data-theme="forest" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">forest</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('pastel')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="pastel" data-act-className="[&amp;_svg]:visible">
									<div data-theme="pastel" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">pastel</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('wireframe')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="wireframe" data-act-className="[&amp;_svg]:visible">
									<div data-theme="wireframe" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">wireframe</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('black')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="black" data-act-className="[&amp;_svg]:visible">
									<div data-theme="black" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">black</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('luxury')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="luxury" data-act-className="[&amp;_svg]:visible">
									<div data-theme="luxury" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">luxury</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('dracula')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="dracula" data-act-className="[&amp;_svg]:visible">
									<div data-theme="dracula" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">dracula</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('cmyk')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="cmyk" data-act-className="[&amp;_svg]:visible">
									<div data-theme="cmyk" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">cmyk</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('autumn')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="autumn" data-act-className="[&amp;_svg]:visible">
									<div data-theme="autumn" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">autumn</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('business')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="business" data-act-className="[&amp;_svg]:visible">
									<div data-theme="business" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">business</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('acid')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="acid" data-act-className="[&amp;_svg]:visible">
									<div data-theme="acid" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">acid</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('lemonade')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="lemonade" data-act-className="[&amp;_svg]:visible">
									<div data-theme="lemonade" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">lemonade</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
								<button onClick={()=>{theme('night')}} className="outline-base-content overflow-hidden rounded-lg text-left w-full" data-set-theme="night" data-act-className="[&amp;_svg]:visible">
									<div data-theme="night" className="bg-base-100 text-base-content w-full cursor-pointer font-sans">
										<div className="grid grid-cols-5 grid-rows-3">
											<div className="col-span-5 row-span-3 row-start-1 flex items-center gap-2 px-4 py-3">
												<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="currentColor" className="invisible h-3 w-3 shrink-0">
													<path d="M20.285 2l-11.285 11.567-5.286-5.011-3.714 3.716 9 8.728 15-15.285z"></path>
												</svg>
												<div className="flex-grow text-sm">night</div>
												<div className="flex h-full flex-shrink-0 flex-wrap gap-1" data-svelte-h="svelte-izuv7l">
													<div className="bg-primary w-2 rounded"></div>
													<div className="bg-secondary w-2 rounded"></div>
													<div className="bg-accent w-2 rounded"></div>
													<div className="bg-neutral w-2 rounded"></div>
												</div>
											</div>
										</div>
									</div>
								</button>
							</ul>
						</div>

		<button className="btn sm:btn-md btn-sm btn-primary flex flex-nowrap flex-row" onClick={()=>document.getElementById('my_modal_5').showModal()}>
			<svg className="min-w-[2.8em]" fill="#1d3d4d" viewBox="0 0 24 24" id="share-alt" data-name="Flat Color" xmlns="http://www.w3.org/2000/svg"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path id="secondary" d="M21.62,6.22l-5-4a1,1,0,0,0-1.05-.12A1,1,0,0,0,15,3V4.19a9.79,9.79,0,0,0-7,7.65,1,1,0,0,0,.62,1.09A1,1,0,0,0,9,13a1,1,0,0,0,.83-.45C11,10.78,13.58,10.24,15,10.07V11a1,1,0,0,0,.57.9,1,1,0,0,0,1.05-.12l5-4a1,1,0,0,0,0-1.56Z" style={{fill:"#2ca9bc"}}></path><path id="primary" d="M17.25,12.56A2,2,0,0,1,16,13a1.94,1.94,0,0,1-.86-.2A2,2,0,0,1,14,11.25a5.44,5.44,0,0,0-3.36,1.86A2,2,0,0,1,9,14a2.07,2.07,0,0,1-.74-.14A2,2,0,0,1,7,11.67,11.13,11.13,0,0,1,12.7,4H4A2,2,0,0,0,2,6V19a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V9a.83.83,0,0,0,0-.22Z" style={{fill:"#1d3d4d"}}></path></g></svg>
			<span className="font-bold md:block hidden">Share</span>
		</button>
		<dialog id="my_modal_5" className="modal modal-bottom sm:modal-middle">
			<div className="modal-box bg-accent lg:max-w-[66%]">
				<Share data={JSON.stringify(services)} />
				<div className="modal-action btn btn-secondary sticky bottom-0 p-4 rounded-lg h-auto w-[90%] m-auto mt-[1em]">
					<form method="dialog">
						<div onClick={()=>{navigator.clipboard.writeText(services.url)}} className="btn btn-info mr-4">Copy</div>
						<button className="btn btn-info">Close</button>
					</form>
				</div>
			</div>
		</dialog>
  </div>
  </div>
          </>
    );
}

export default Nav;
